@@ -2,6 +2,7 @@
 import logging
 import numpy as np
 from typing import Dict, Optional
+import regex as re
 
 
 logger = logging.getLogger(__name__)
@@ -20,6 +21,14 @@ def _get_is_negative(offset_string: str) -> bool:
         if offset_string.count('S') == 1 and offset_string[-1] == "S" and is_negative is False:
             is_negative = True
 
+    if (
+        offset_string[0] == '*'
+        and offset_string.count('*') == 1
+        and offset_string.count('(') == 1
+        and offset_string.count(')') == 1
+    ):
+        is_negative = True
+
     offset_string_negative_check = (
         offset_string.replace(' ', '')
         .replace('"', '')
@@ -100,6 +109,18 @@ def _normalize_string_to_absolute_float(offset_string: str) -> Optional[float]:
     if offset_string.lower() in ['zwölf', 'twelve']:
         return 12.0
 
+    # check for major spaces
+    if re.search(r'(\d)[ ]{3,}(\d)', offset_string):
+        return None
+
+    offset_string = re.sub(r"(\d)[ ]{1,2}(\d)", r'\1.\2', offset_string)
+
+    if offset_string.count('*') > 1:
+        return None
+
+    if offset_string.count('*') == 1 and offset_string[0] == '*' and offset_string.count('(') == 0:
+        return None
+
     offset_string = (
         offset_string.replace('O', '0')
         .replace('°', '')
@@ -118,6 +139,7 @@ def _normalize_string_to_absolute_float(offset_string: str) -> Optional[float]:
         .replace('-', '')
         .replace('–', '')
         .replace('€', '')
+        .replace('*', '')
     )
 
     if len(offset_string) > 1:
@@ -209,6 +231,7 @@ def _normalize_string_to_absolute_float(offset_string: str) -> Optional[float]:
         _float = float(offset_string.replace(',', ''))  # => 500000
         _float = abs(_float)
         normalization = _float
+
     # check for 500.000
     elif (
         ln > 4
@@ -266,7 +289,7 @@ def _normalize_string_to_absolute_float(offset_string: str) -> Optional[float]:
 
 def normalize_to_percentage(offset_string: str) -> Optional[float]:
     """Given an Annotation this function tries to translate the offset-string to an percentage -a float between 0 -1."""
-    offset_string = offset_string.replace(' ', '').replace('+', '').replace('-', '').replace('"', '').replace('„', '')
+    offset_string = offset_string.replace('+', '').replace('-', '').replace('"', '').replace('„', '')
     if len(offset_string) > 1 and offset_string[-1] in ['.', ';', ',']:
         offset_string = offset_string[:-1]
 
@@ -446,7 +469,10 @@ def _check_for_dates_with_day_count(offset_string: str, org_str: str, month_dict
         translation = _date
     # check for 01.01.01
     elif (
-        len(offset_string) == 8 and offset_string[2] == '.' and offset_string[5] == '.' and offset_string[6:].isdecimal()
+        len(offset_string) == 8
+        and offset_string[2] == '.'
+        and offset_string[5] == '.'
+        and offset_string[6:].isdecimal()
     ):
         year_num = int(offset_string[6:])
 
@@ -458,7 +484,10 @@ def _check_for_dates_with_day_count(offset_string: str, org_str: str, month_dict
         translation = offset_string[:6] + str(cent_num) + offset_string[6:]
     # check for 01/01/01
     elif (
-        len(offset_string) == 8 and offset_string[2] == '/' and offset_string[5] == '/' and offset_string[6:].isdecimal()
+        len(offset_string) == 8
+        and offset_string[2] == '/'
+        and offset_string[5] == '/'
+        and offset_string[6:].isdecimal()
     ):
         year_num = int(offset_string[6:])
 
@@ -582,14 +611,14 @@ def _final_date_check(date_string: str):
             and date_string[:2].isdecimal()
             and date_string[3:5].isdecimal()
         ):
-            logger.warning('Could not convert >>' + date_string + '<< to date (date contains letters)')
+            logger.info('Could not convert >>' + date_string + '<< to date (date contains letters)')
             date_string = None
         elif (
             not ((1900 < int(date_string[-4:]) < 2100) or int(date_string[-4:]) == 0)
             or not (int(date_string[:2]) < 32)
             or not (int(date_string[3:5]) < 13)
         ):
-            logger.warning('Could not convert >>' + date_string + '<< to date (invalid date)')
+            logger.info('Could not convert >>' + date_string + '<< to date (invalid date)')
             date_string = None
     return date_string
 
@@ -627,7 +656,7 @@ def roman_to_float(offset_string: str) -> Optional[float]:
         try:
             value = ROMAN_NUMS[input[i]]
             # If the next place holds a larger number, this value is negative
-            if i+1 < len(input) and ROMAN_NUMS[input[i+1]] > value:
+            if i + 1 < len(input) and ROMAN_NUMS[input[i + 1]] > value:
                 roman_sum -= value
             else:
                 roman_sum += value
