@@ -3,11 +3,12 @@
 import abc
 import logging
 from typing import List
+from copy import deepcopy
 
 import pandas as pd
 
-from konfuzio_sdk.data import Document, Category
-from konfuzio_sdk.evaluate import compare
+from konfuzio_sdk.data import Document, Category, Span
+from konfuzio_sdk.evaluate import compare, Evaluation
 from konfuzio_sdk.utils import sdk_isinstance
 
 logger = logging.getLogger(__name__)
@@ -34,7 +35,7 @@ class ProcessingStep:
 
 
 class AbstractTokenizer(metaclass=abc.ABCMeta):
-    """Abstract definition of a tokenizer."""
+    """Abstract definition of a Tokenizer."""
 
     processing_steps = []
 
@@ -42,6 +43,14 @@ class AbstractTokenizer(metaclass=abc.ABCMeta):
         """Return string representation of the class."""
         return f"{self.__class__.__name__}"
 
+    @abc.abstractmethod
+    def __eq__(self, other) -> bool:
+        """Check if two Tokenizers are the same."""
+
+    @abc.abstractmethod
+    def __hash__(self):
+        """Get unique hash for Tokenizer."""
+
     @abc.abstractmethod
     def fit(self, category: Category):
         """Fit the tokenizer accordingly with the Documents of the Category."""
@@ -50,43 +59,60 @@ class AbstractTokenizer(metaclass=abc.ABCMeta):
     def tokenize(self, document: Document):
         """Create Annotations with 1 Span based on the result of the Tokenizer."""
 
+    @abc.abstractmethod
+    def found_spans(self, document: Document) -> List[Span]:
+        """Find all Spans in a Document that can be found by a Tokenizer."""
+
     def evaluate(self, document: Document) -> pd.DataFrame:
         """
         Compare a Document with its tokenized version.
 
         :param document: Document to evaluate
-        :return: Evaluation DataFrame and Processing time DataFrame.
+        :return: Evaluation DataFrame
         """
         assert sdk_isinstance(document, Document)
+        document.annotations()  # Load Annotations before doing tokenization
 
-        virtual_doc = Document(
-            project=document.category.project,
-            text=document.text,
-            bbox=document.get_bbox(),
-            category=document.category,
-            copy_of_id=document.id_,
-        )
-
+        virtual_doc = deepcopy(document)
         self.tokenize(virtual_doc)
-        return compare(document, virtual_doc)
+        evaluation = compare(document, virtual_doc)
+        logger.warning(
+            f'{evaluation["tokenizer_true_positive"].sum()} of {evaluation["is_correct"].sum()} corrects'
+            f' Spans are found by Tokenizer'
+        )
+        return evaluation
 
-    def evaluate_category(self, category: Category) -> pd.DataFrame:
-        """Compare test Documents of a Category with their tokenized version.
-
-        :param category: Category to evaluate
-        :return: Evaluation DataFrame containing the evaluation of all Documents in the Category.
+    def evaluate_dataset(self, dataset_documents: List[Document]) -> Evaluation:
         """
-        assert isinstance(category, Category)
+        Evaluate the tokenizer on a dataset of documents.
 
-        if not category.test_documents():
-            raise ValueError(f"Category {category.__repr__()} has no test documents.")
+        :param dataset_documents: Documents to evaluate
+        :return: Evaluation instance
+        """
+        eval_list = []
+        for document in dataset_documents:
+            assert sdk_isinstance(document, Document), f"Invalid document type: {type(document)}. Should be Document."
+            document.annotations()  # Load Annotations before doing tokenization
+            virtual_doc = deepcopy(document)
+            self.tokenize(virtual_doc)
+            eval_list.append((document, virtual_doc))
+        return Evaluation(eval_list)
 
-        evaluation = []
-        for document in category.test_documents():
-            doc_evaluation = self.evaluate(document)
-            evaluation.append(doc_evaluation)
+    def missing_spans(self, document: Document) -> List[Span]:
+        """
+        Apply a Tokenizer on a Document and find all Spans that cannot be found.
 
-        return pd.concat(evaluation, ignore_index=True)
+        Use this approach to sequentially work on remaining Spans after a Tokenizer ran on a List of Documents.
+
+        :param document: A Document
+
+        :return: A list containing all missing Spans.
+
+        """
+        self.found_spans(document)
+        missing_spans_list = [span for span in document.spans(use_correct=True) if span.regex_matching == []]
+
+        return missing_spans_list
 
     def get_runtime_info(self) -> pd.DataFrame:
         """
@@ -107,12 +133,23 @@ class ListTokenizer(AbstractTokenizer):
 
     def __init__(self, tokenizers: List['AbstractTokenizer']):
         """Initialize the list of tokenizers."""
-        self.tokenizers = tokenizers
+        self.tokenizers = list(dict.fromkeys(tokenizers))
         self.processing_steps = []
 
+    def __eq__(self, other) -> bool:
+        """Compare ListTokenizer with another Tokenizer."""
+        if type(other) is ListTokenizer:
+            return self.tokenizers == other.tokenizers
+        else:
+            return False
+
+    def __hash__(self):
+        """Get unique hash for ListTokenizer."""
+        return hash(tuple(self.tokenizers))
+
     def fit(self, category: Category):
         """Call fit on all tokenizers."""
-        assert isinstance(category, Category)
+        assert sdk_isinstance(category, Category)
 
         for tokenizer in self.tokenizers:
             tokenizer.fit(category)
@@ -122,12 +159,28 @@ class ListTokenizer(AbstractTokenizer):
         assert sdk_isinstance(document, Document)
 
         for tokenizer in self.tokenizers:
+            # todo: running multiple tokenizers on one document
+            #  should support that multiple Tokenizers can create identical Spans
             tokenizer.tokenize(document)
             if tokenizer.processing_steps:
                 self.processing_steps.append(tokenizer.processing_steps[-1])
 
         return document
 
+    def found_spans(self, document: Document) -> List[Span]:
+        """Run found_spans in the given order on a Document."""
+        found_spans_list = []
+        for tokenizer in self.tokenizers:
+            found_spans_list += tokenizer.found_spans(document)
+        return found_spans_list
+
+    def span_match(self, span: 'Span') -> bool:
+        """Run span_match in the given order."""
+        for tokenizer in self.tokenizers:
+            if tokenizer.span_match(span):
+                return True
+        return False
+
     def lose_weight(self):
         """Delete processing steps."""
         self.processing_steps = []
